bayespy.inference.vmp.nodes.binomial.BinomialMoments.add_converter
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialMoments.add_converter